==> react-primitive-typography-0.1.0.tgz: package/lib/useTypography.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["design", "variant", "as", "fontSize", "fontFamily", "fontWeight", "fontStyle", "fontStretch", "letterSpacing", "lineHeight", "textDecorationLine", "isLinked", "isBlurred", "children"],
  _excluded2 = ["className"];
import cx from 'classnames';
import merge from 'lodash.merge';
import { BASE_CLASS, DESIGN, KIND, TEXT_DECORATION_LINE, VARIANT } from './config.js';
var getInheritedProps = function getInheritedProps(_ref) {
  var design = _ref.design,
    variant = _ref.variant;
  if (typeof KIND[design] === 'object') {
    if (typeof KIND[design][variant] === 'object') {
      return KIND[design][variant];
    }
  }
  return {};
};
var getLinkProps = function getLinkProps(_ref2, props) {
  var isLinked = _ref2.isLinked;
  return _extends({}, props, isLinked && {
    textDecorationLine: TEXT_DECORATION_LINE.UNDERLINE
  });
};
var getClassNames = function getClassNames(_ref3) {
  var _cx;
  var design = _ref3.design,
    variant = _ref3.variant,
    fontSize = _ref3.fontSize,
    fontFamily = _ref3.fontFamily,
    fontWeight = _ref3.fontWeight,
    fontStyle = _ref3.fontStyle,
    fontStretch = _ref3.fontStretch,
    letterSpacing = _ref3.letterSpacing,
    lineHeight = _ref3.lineHeight,
    textDecorationLine = _ref3.textDecorationLine,
    className = _ref3.className,
    isBlurred = _ref3.isBlurred,
    isLinked = _ref3.isLinked;
  return cx(BASE_CLASS, [BASE_CLASS + "-design-" + design, BASE_CLASS + "-variant-" + variant], (_cx = {}, _cx[BASE_CLASS + "-linked"] = isLinked, _cx[BASE_CLASS + "-fontSize-" + fontSize] = fontSize !== undefined, _cx[BASE_CLASS + "-fontFamily-" + fontFamily] = fontFamily !== undefined, _cx[BASE_CLASS + "-fontWeight-" + fontWeight] = fontWeight !== undefined, _cx[BASE_CLASS + "-fontStyle-" + fontStyle] = fontStyle !== undefined, _cx[BASE_CLASS + "-fontStretch-" + fontStretch] = fontStretch !== undefined, _cx[BASE_CLASS + "-letterSpacing-" + letterSpacing] = letterSpacing !== undefined, _cx[BASE_CLASS + "-lineHeight-" + lineHeight] = lineHeight !== undefined, _cx[BASE_CLASS + "-textDecorationLine-" + textDecorationLine] = textDecorationLine !== undefined, _cx[BASE_CLASS + "-blurred-" + isBlurred] = isBlurred !== undefined, _cx.className = className, _cx));
};
var useTypography = function useTypography(_ref4) {
  var _ref4$design = _ref4.design,
    design = _ref4$design === void 0 ? DESIGN.BODY_1 : _ref4$design,
    _ref4$variant = _ref4.variant,
    variant = _ref4$variant === void 0 ? VARIANT.DEFAULT : _ref4$variant,
    as = _ref4.as,
    fontSize = _ref4.fontSize,
    fontFamily = _ref4.fontFamily,
    fontWeight = _ref4.fontWeight,
    fontStyle = _ref4.fontStyle,
    fontStretch = _ref4.fontStretch,
    letterSpacing = _ref4.letterSpacing,
    lineHeight = _ref4.lineHeight,
    textDecorationLine = _ref4.textDecorationLine,
    isLinked = _ref4.isLinked,
    isBlurred = _ref4.isBlurred,
    children = _ref4.children,
    props = _objectWithoutPropertiesLoose(_ref4, _excluded);
  var _getLinkProps = getLinkProps({
      isLinked: isLinked
    }, getInheritedProps({
      design: design,
      variant: variant
    })),
    inheritedClassName = _getLinkProps.className,
    inheritedProps = _objectWithoutPropertiesLoose(_getLinkProps, _excluded2);
  var className = getClassNames(merge(inheritedProps, _extends({}, props, {
    design: design,
    variant: variant,
    fontSize: fontSize,
    fontFamily: fontFamily,
    fontWeight: fontWeight,
    fontStyle: fontStyle,
    fontStretch: fontStretch,
    letterSpacing: letterSpacing,
    lineHeight: lineHeight,
    textDecorationLine: textDecorationLine,
    isBlurred: isBlurred,
    isLinked: isLinked
  })));
  return _extends({}, props, _extends({
    className: className
  }, as && {
    as: as
  }), {
    children: children
  });
};
export default useTypography;

==> react-primitive-typography-0.2.0.tgz: package/lib/useTypography.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
var _excluded = ["design", "variant", "as", "fontSize", "fontFamily", "fontWeight", "fontStyle", "fontStretch", "letterSpacing", "lineHeight", "textDecorationLine", "isLinked", "isBlurred", "children"],
  _excluded2 = ["className"];
import cx from 'classnames';
import merge from 'lodash.merge';
import { BASE_CLASS, DESIGN, KIND, TEXT_DECORATION_LINE, VARIANT } from './config.js';
var getInheritedProps = function getInheritedProps(_ref) {
  var design = _ref.design,
    variant = _ref.variant;
  if (typeof KIND[design] === 'object') {
    if (typeof KIND[design][variant] === 'object') {
      return KIND[design][variant];
    }
  }
  return {};
};
var getLinkProps = function getLinkProps(_ref2, props) {
  var isLinked = _ref2.isLinked;
  return _extends({}, props, isLinked && {
    textDecorationLine: TEXT_DECORATION_LINE.UNDERLINE
  });
};
var getClassNames = function getClassNames(_ref3) {
  var _cx;
  var design = _ref3.design,
    variant = _ref3.variant,
    fontSize = _ref3.fontSize,
    fontFamily = _ref3.fontFamily,
    fontWeight = _ref3.fontWeight,
    fontStyle = _ref3.fontStyle,
    fontStretch = _ref3.fontStretch,
    letterSpacing = _ref3.letterSpacing,
    lineHeight = _ref3.lineHeight,
    textDecorationLine = _ref3.textDecorationLine,
    className = _ref3.className,
    isBlurred = _ref3.isBlurred,
    isLinked = _ref3.isLinked;
  return cx(BASE_CLASS, [BASE_CLASS + "-design-" + design, BASE_CLASS + "-variant-" + variant], (_cx = {}, _cx[BASE_CLASS + "-linked"] = isLinked, _cx[BASE_CLASS + "-fontSize-" + fontSize] = fontSize !== undefined, _cx[BASE_CLASS + "-fontFamily-" + fontFamily] = fontFamily !== undefined, _cx[BASE_CLASS + "-fontWeight-" + fontWeight] = fontWeight !== undefined, _cx[BASE_CLASS + "-fontStyle-" + fontStyle] = fontStyle !== undefined, _cx[BASE_CLASS + "-fontStretch-" + fontStretch] = fontStretch !== undefined, _cx[BASE_CLASS + "-letterSpacing-" + letterSpacing] = letterSpacing !== undefined, _cx[BASE_CLASS + "-lineHeight-" + lineHeight] = lineHeight !== undefined, _cx[BASE_CLASS + "-textDecorationLine-" + textDecorationLine] = textDecorationLine !== undefined, _cx[BASE_CLASS + "-blurred-" + isBlurred] = isBlurred !== undefined, _cx), className);
};
var useTypography = function useTypography(_ref4) {
  var _ref4$design = _ref4.design,
    design = _ref4$design === void 0 ? DESIGN.BODY_1 : _ref4$design,
    _ref4$variant = _ref4.variant,
    variant = _ref4$variant === void 0 ? VARIANT.DEFAULT : _ref4$variant,
    as = _ref4.as,
    fontSize = _ref4.fontSize,
    fontFamily = _ref4.fontFamily,
    fontWeight = _ref4.fontWeight,
    fontStyle = _ref4.fontStyle,
    fontStretch = _ref4.fontStretch,
    letterSpacing = _ref4.letterSpacing,
    lineHeight = _ref4.lineHeight,
    textDecorationLine = _ref4.textDecorationLine,
    isLinked = _ref4.isLinked,
    isBlurred = _ref4.isBlurred,
    children = _ref4.children,
    props = _objectWithoutPropertiesLoose(_ref4, _excluded);
  var _getLinkProps = getLinkProps({
      isLinked: isLinked
    }, getInheritedProps({
      design: design,
      variant: variant
    })),
    inheritedClassName = _getLinkProps.className,
    inheritedProps = _objectWithoutPropertiesLoose(_getLinkProps, _excluded2);
  var className = getClassNames(merge(inheritedProps, _extends({}, props, {
    design: design,
    variant: variant,
    fontSize: fontSize,
    fontFamily: fontFamily,
    fontWeight: fontWeight,
    fontStyle: fontStyle,
    fontStretch: fontStretch,
    letterSpacing: letterSpacing,
    lineHeight: lineHeight,
    textDecorationLine: textDecorationLine,
    isBlurred: isBlurred,
    isLinked: isLinked
  })));
  return _extends({}, props, _extends({
    className: className
  }, as && {
    as: as
  }), {
    children: children
  });
};
export default useTypography;
